XApiEx.Api.BatchCompliance (x_api_ex v1.0.0)

API calls for all endpoints tagged BatchCompliance.

Summary

Functions

Create a batch compliance job Creates a new compliance job for Post IDs or user IDs. A compliance job will contain an ID and a destination URL. The destination URL represents the location that contains the list of IDs consumed by your App For full details, see the API reference for this endpoint. Sign up for the X API

Get a compliance job by ID Get a single compliance job with the specified ID. For full details, see the API reference for this endpoint. Sign up for the X API

Get all batch compliance jobs Returns a list of recent compliance jobs. For full details, see the API reference for this endpoint. Sign up for the X API

Functions

create_a_batch_compliance_job(connection, opts \\ [])

@spec create_a_batch_compliance_job(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.ComplianceJobResponse.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:error, Tesla.Env.t()}

Create a batch compliance job Creates a new compliance job for Post IDs or user IDs. A compliance job will contain an ID and a destination URL. The destination URL represents the location that contains the list of IDs consumed by your App For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :body (CreateABatchComplianceJobRequest):

Returns

  • {:ok, XApiEx.Model.ComplianceJobResponse.t} on success
  • {:error, Tesla.Env.t} on failure

get_a_compliance_job_by_id(connection, id, opts \\ [])

@spec get_a_compliance_job_by_id(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.ComplianceJobResponse.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:error, Tesla.Env.t()}

Get a compliance job by ID Get a single compliance job with the specified ID. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • id (String.t):
  • opts (keyword): Optional parameters

Returns

  • {:ok, XApiEx.Model.ComplianceJobResponse.t} on success
  • {:error, Tesla.Env.t} on failure

get_all_batch_compliance_jobs(connection, opts \\ [])

@spec get_all_batch_compliance_jobs(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.ComplianceJobsResponse.t()}
  | {:error, Tesla.Env.t()}

Get all batch compliance jobs Returns a list of recent compliance jobs. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :type (String.t):

Returns

  • {:ok, XApiEx.Model.ComplianceJobsResponse.t} on success
  • {:error, Tesla.Env.t} on failure