XApiEx.Api.ManagePosts (x_api_ex v1.0.0)

API calls for all endpoints tagged ManagePosts.

Summary

Functions

Create a Post Allows an authenticated user to create a Post. You can add parameters to post polls, quote Posts, Post with reply settings, and Post to Super Followers in addition to other features. For full details, see the API reference for this endpoint. Sign up for the X API

Delete a Post Allows an authenticated user to delete a Post. For full details, see the API reference for this endpoint. Sign up for the X API

Functions

create_a_post(connection, opts \\ [])

@spec create_a_post(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.CreateAPost200Response.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:error, Tesla.Env.t()}

Create a Post Allows an authenticated user to create a Post. You can add parameters to post polls, quote Posts, Post with reply settings, and Post to Super Followers in addition to other features. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :body (CreateAPostRequest):

Returns

  • {:ok, XApiEx.Model.CreateAPost200Response.t} on success
  • {:error, Tesla.Env.t} on failure

delete_a_post(connection, id, opts \\ [])

@spec delete_a_post(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.DeleteAPost200Response.t()}
  | {:error, Tesla.Env.t()}

Delete a Post Allows an authenticated user to delete a Post. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • id (String.t): The ID of the Post you wish to delete
  • opts (keyword): Optional parameters

Returns

  • {:ok, XApiEx.Model.DeleteAPost200Response.t} on success
  • {:error, Tesla.Env.t} on failure