XApiEx.Api.Metadata (x_api_ex v1.0.0)

API calls for all endpoints tagged Metadata.

Summary

Functions

Create Media Metadata Allows an authenticated user to add metadata to uploaded media. You can use this endpoint to attach alt text to media. The media_id parameter specifies the media, while the alt_text contains the descriptive text. For full details, see the API reference for this endpoint. To get started, sign up for the X API.

Functions

create_media_metadata(connection, opts \\ [])

@spec create_media_metadata(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.CreateMediaMetadata200Response.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:error, Tesla.Env.t()}

Create Media Metadata Allows an authenticated user to add metadata to uploaded media. You can use this endpoint to attach alt text to media. The media_id parameter specifies the media, while the alt_text contains the descriptive text. For full details, see the API reference for this endpoint. To get started, sign up for the X API.

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :body (CreateMediaMetadataRequest):

Returns

  • {:ok, XApiEx.Model.CreateMediaMetadata200Response.t} on success
  • {:error, Tesla.Env.t} on failure