XApiEx.Api.Reposts (x_api_ex v1.0.0)

API calls for all endpoints tagged Reposts.

Summary

Functions

Repost a post Allows an authenticated user to Repost a post. For full details, see the API reference for this endpoint. Sign up for the X API

Reposted by Returns a list of users who have liked a specified Post ID. For full details, see the API reference for this endpoint. Sign up for the X API

Undo a Repost Allows an authenticated user to undo a Repost of a post. For full details, see the API reference for this endpoint. Sign up for the X API

Functions

repost_a_post(connection, id, opts \\ [])

@spec repost_a_post(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.RepostAPost200Response.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:error, Tesla.Env.t()}

Repost a post Allows an authenticated user to Repost a post. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • id (String.t): The ID of the user who wishes to Repost a Post. The ID must belong to the authenticating user.
  • opts (keyword): Optional parameters
    • :body (RepostAPostRequest):

Returns

  • {:ok, XApiEx.Model.RepostAPost200Response.t} on success
  • {:error, Tesla.Env.t} on failure

reposted_by(connection, id, opts \\ [])

@spec reposted_by(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.PostsResponse.t()}
  | {:error, Tesla.Env.t()}

Reposted by Returns a list of users who have liked a specified Post ID. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • id (String.t): Required. The Post ID of the Post to request Reposting users of.
  • opts (keyword): Optional parameters
    • :"user.fields" (String.t): Comma-separated fields for the user object. Allowed values: created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified,withheld Default values: id,name,username
    • :expansions (String.t): Expansions enable requests to expand an ID into a full object in the includes response object. Allowed value: pinned_tweet_id Default value: none
    • :"tweet.fields" (String.t): Comma-separated list of fields for the Tweet object. Expansion required. Allowed values: attachments,author_id,context_annotations,conversation_id,created_at,entities,geo,id,in_reply_to_user_id,lang,non_public_metrics,organic_metrics,possibly_sensitive,promoted_metrics,public_metrics,referenced_tweets,source,text,withheld,edit_history_tweet_ids,edit_controls Default values: id,text,edit_history_tweet_ids OAuth1.0a User Context authorization required if any of the following fields are included in the request: non_public_metrics,organic_metrics,promoted_metrics
    • :max_results (String.t): The maximum number of results to be returned by a request. Allowed values: 1 through 100. Default value: 100
    • :pagination_token (String.t): This parameter is used to get the next 'page' of results. The value used with the parameter is pulled directly from the response provided by the API, and should not be modified.

Returns

  • {:ok, XApiEx.Model.PostsResponse.t} on success
  • {:error, Tesla.Env.t} on failure

undo_a_repost(connection, id, source_tweet_id, opts \\ [])

@spec undo_a_repost(Tesla.Env.client(), String.t(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, XApiEx.Model.UndoARepost200Response.t()}
  | {:ok, XApiEx.Model.ApiError.t()}
  | {:error, Tesla.Env.t()}

Undo a Repost Allows an authenticated user to undo a Repost of a post. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • id (String.t): The ID of the user who wishes to undo a Repost. The ID must belong to the authenticating user.
  • source_tweet_id (String.t): The ID of the Post to remove of Repost of
  • opts (keyword): Optional parameters

Returns

  • {:ok, XApiEx.Model.UndoARepost200Response.t} on success
  • {:error, Tesla.Env.t} on failure