XApiEx.Api.UserLookup (x_api_ex v1.0.0)

API calls for all endpoints tagged UserLookup.

Summary

Functions

Authenticated User Lookup This endpoint returns the information about an authorized user. For full details, see the API reference for this endpoint. Sign up for the X API

User by ID This endpoint returns details about a user by ID. For full details, see the API reference for this endpoint. Sign up for the X API

User by Username This endpoint returns details about a user by username. For full details, see the API reference for this endpoint. Sign up for the X API

Users by ID This endpoint returns details about up to 100 users by ID. For full details, see the API reference for this endpoint. Sign up for the X API

Users by Username This endpoint returns details about up to 100 users specified by username. For full details, see the API reference for this endpoint. Sign up for the X API

Functions

authenticated_user_lookup(connection, opts \\ [])

@spec authenticated_user_lookup(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, nil}
  | {:ok, XApiEx.Model.UsersResponse.t()}
  | {:ok, XApiEx.Model.UsersByUsername400Response.t()}
  | {:error, Tesla.Env.t()}

Authenticated User Lookup This endpoint returns the information about an authorized user. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :"user.fields" (String.t): Comma-separated fields for the user object. Allowed values: created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified,withheld Default values: id,name,username
    • :expansions (String.t): Expansions enable requests to expand an ID into a full object in the includes response object. Allowed value: pinned_tweet_id Default value: none
    • :"tweet.fields" (String.t): Comma-separated list of fields for the Tweet object. Expansion required. Allowed values: attachments,author_id,context_annotations,conversation_id,created_at,entities,geo,id,in_reply_to_user_id,lang,non_public_metrics,organic_metrics,possibly_sensitive,promoted_metrics,public_metrics,referenced_tweets,reply_settings,source,text,withheld Default values: id,text OAuth1.0a User Context authorization required if any of the following fields are included in the request: non_public_metrics,organic_metrics,promoted_metrics

Returns

  • {:ok, XApiEx.Model.UsersResponse.t} on success
  • {:error, Tesla.Env.t} on failure

user_by_id(connection, id, opts \\ [])

@spec user_by_id(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, nil}
  | {:ok, XApiEx.Model.UserResponse.t()}
  | {:error, Tesla.Env.t()}

User by ID This endpoint returns details about a user by ID. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • id (String.t): Required. Enter a single user ID.
  • opts (keyword): Optional parameters
    • :"user.fields" (String.t): Comma-separated fields for the user object. Allowed values: created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified,withheld Default values: id,name,username
    • :expansions (String.t): Expansions enable requests to expand an ID into a full object in the includes response object. Allowed value: pinned_tweet_id Default value: none
    • :"tweet.fields" (String.t): Comma-separated list of fields for the Tweet object. Expansion required. Allowed values: attachments,author_id,context_annotations,conversation_id,created_at,entities,geo,id,in_reply_to_user_id,lang,non_public_metrics,organic_metrics,possibly_sensitive,promoted_metrics,public_metrics,referenced_tweets,reply_settings,source,text,withheld Default values: id,text OAuth1.0a User Context authorization required if any of the following fields are included in the request: non_public_metrics,organic_metrics,promoted_metrics

Returns

  • {:ok, XApiEx.Model.UserResponse.t} on success
  • {:error, Tesla.Env.t} on failure

user_by_username(connection, username, opts \\ [])

@spec user_by_username(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, nil}
  | {:ok, XApiEx.Model.UserResponse.t()}
  | {:error, Tesla.Env.t()}

User by Username This endpoint returns details about a user by username. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • username (String.t): Required. Enter a single X username (handle).
  • opts (keyword): Optional parameters
    • :"user.fields" (String.t): Comma-separated fields for the user object. Allowed values: created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified,withheld Default values: id,name,username
    • :expansions (String.t): Expansions enable requests to expand an ID into a full object in the includes response object. Allowed value: pinned_tweet_id Default value: none
    • :"tweet.fields" (String.t): Comma-separated list of fields for the Tweet object. Expansion required. Allowed values: attachments,author_id,context_annotations,conversation_id,created_at,entities,geo,id,in_reply_to_user_id,lang,non_public_metrics,organic_metrics,possibly_sensitive,promoted_metrics,public_metrics,referenced_tweets,source,text,withheld Default values: id,text OAuth1.0a User Context authorization required if any of the following fields are included in the request: non_public_metrics,organic_metrics,promoted_metrics

Returns

  • {:ok, XApiEx.Model.UserResponse.t} on success
  • {:error, Tesla.Env.t} on failure

users_by_id(connection, opts \\ [])

Users by ID This endpoint returns details about up to 100 users by ID. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :ids (String.t): Required. Enter up to 100 comma-separated user IDs.
    • :"user.fields" (String.t): Comma-separated fields for the user object. Allowed values: created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified,withheld Default values: id,name,username
    • :expansions (String.t): Expansions enable requests to expand an ID into a full object in the includes response object. Allowed value: pinned_tweet_id Default value: none
    • :"tweet.fields" (String.t): Comma-separated list of fields for the Tweet object. Expansion required. Allowed values: attachments,author_id,context_annotations,conversation_id,created_at,entities,geo,id,in_reply_to_user_id,lang,non_public_metrics,organic_metrics,possibly_sensitive,promoted_metrics,public_metrics,referenced_tweets,reply_settings,source,text,withheld Default values: id,text OAuth1.0a User Context authorization required if any of the following fields are included in the request: non_public_metrics,organic_metrics,promoted_metrics

Returns

  • {:ok, XApiEx.Model.UsersResponse.t} on success
  • {:error, Tesla.Env.t} on failure

users_by_username(connection, opts \\ [])

@spec users_by_username(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, XApiEx.Model.ApiError.t()}
  | {:ok, nil}
  | {:ok, XApiEx.Model.UsersResponse.t()}
  | {:ok, XApiEx.Model.UsersByUsername400Response.t()}
  | {:error, Tesla.Env.t()}

Users by Username This endpoint returns details about up to 100 users specified by username. For full details, see the API reference for this endpoint. Sign up for the X API

Parameters

  • connection (XApiEx.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :usernames (String.t): Required. Enter up to 100 comma-separated usernames.
    • :"user.fields" (String.t): Comma-separated fields for the user object. Allowed values: created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified,withheld Default values: id,name,username
    • :expansions (String.t): Expansions enable requests to expand an ID into a full object in the includes response object. Allowed value: pinned_tweet_id Default value: none
    • :"tweet.fields" (String.t): Comma-separated list of fields for the Tweet object. Expansion required. Allowed values: attachments,author_id,context_annotations,conversation_id,created_at,entities,geo,id,in_reply_to_user_id,lang,non_public_metrics,organic_metrics,possibly_sensitive,promoted_metrics,public_metrics,referenced_tweets,reply_settings,source,text,withheld Default values: id,text OAuth1.0a User Context authorization required if any of the following fields are included in the request: non_public_metrics,organic_metrics,promoted_metrics

Returns

  • {:ok, XApiEx.Model.UsersResponse.t} on success
  • {:error, Tesla.Env.t} on failure