XApiEx.Model.DmResponse (x_api_ex v1.0.0)

Response wrapper for a single new DM event (201 Created).

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.DmResponse{data: XApiEx.Model.DmMessage.t() | nil}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.