XApiEx.Model.FilterRulesResponse (x_api_ex v1.0.0)

Response wrapper for filtered stream rules.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.FilterRulesResponse{
  data: [XApiEx.Model.FilterRule.t()] | nil,
  errors: [XApiEx.Model.ApiError.t()] | nil,
  meta: XApiEx.Model.FilterRulesMeta.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.