XApiEx.Model.ListResponse (x_api_ex v1.0.0)

Response wrapper for a single X List.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.ListResponse{
  data: XApiEx.Model.ListById200ResponseData.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.