XApiEx.Model.Media (x_api_ex v1.0.0)

A media object attached to a post.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.Media{
  duration_ms: number() | nil,
  height: number() | nil,
  media_key: String.t() | nil,
  preview_image_url: String.t() | nil,
  public_metrics: XApiEx.Model.Media.PublicMetrics.t() | nil,
  type: String.t() | nil,
  url: String.t() | nil,
  width: number() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.