XApiEx.Model.NewGroupDmAndConversationRequest (x_api_ex v1.0.0)

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.NewGroupDmAndConversationRequest{
  conversation_type: String.t() | nil,
  message: XApiEx.Model.NewGroupDmAndConversationRequest.Message.t() | nil,
  participant_ids: [String.t()] | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.