XApiEx.Model.PinAList200Response (x_api_ex v1.0.0)

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.PinAList200Response{
  data: XApiEx.Model.PinAList200ResponseData.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.