XApiEx.Model.Place (x_api_ex v1.0.0)

A geographic place object.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.Place{
  contained_within: [String.t()] | nil,
  country: String.t() | nil,
  country_code: String.t() | nil,
  full_name: String.t() | nil,
  geo: XApiEx.Model.Place.Geo.t() | nil,
  id: String.t() | nil,
  name: String.t() | nil,
  place_type: String.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.