XApiEx.Model.Poll (x_api_ex v1.0.0)

A poll attached to a Tweet.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.Poll{
  duration_minutes: number() | nil,
  end_datetime: String.t() | nil,
  id: String.t() | nil,
  options: [XApiEx.Model.PollOption.t()] | nil,
  voting_status: String.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.