XApiEx.Model.Post (x_api_ex v1.0.0)

A post (tweet) object with full field support.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.Post{
  attachments: XApiEx.Model.Post.Attachments.t() | nil,
  author_id: String.t() | nil,
  conversation_id: String.t() | nil,
  created_at: String.t() | nil,
  edit_history_tweet_ids: [String.t()] | nil,
  entities: XApiEx.Model.Post.Entities.t() | nil,
  geo: XApiEx.Model.Post.Geo.t() | nil,
  id: String.t() | nil,
  in_reply_to_user_id: String.t() | nil,
  lang: String.t() | nil,
  possibly_sensitive: boolean() | nil,
  referenced_tweets: [XApiEx.Model.Post.ReferencedPost.t()] | nil,
  source: String.t() | nil,
  text: String.t() | nil,
  username: String.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.