XApiEx.Model.Post.Entities (x_api_ex v1.0.0)

Entities extracted from a post (hashtags, mentions, URLs).

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.Post.Entities{
  hashtags: [XApiEx.Model.Post.Entities.Hashtag.t()] | nil,
  mentions: [XApiEx.Model.Post.Entities.Mention.t()] | nil,
  urls: [XApiEx.Model.Post.Entities.Url.t()] | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.