XApiEx.Model.Post.Entities.Url (x_api_ex v1.0.0)

A URL entity within a post.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.Post.Entities.Url{
  description: String.t() | nil,
  display_url: String.t() | nil,
  end: number() | nil,
  expanded_url: String.t() | nil,
  images: [XApiEx.Model.Post.Entities.UrlImage.t()] | nil,
  start: number() | nil,
  status: number() | nil,
  title: String.t() | nil,
  unwound_url: String.t() | nil,
  url: String.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.