XApiEx.Model.SearchResponse (x_api_ex v1.0.0)

Response wrapper for post search results (recent and full-archive).

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.SearchResponse{
  data: [XApiEx.Model.Post.t()] | nil,
  includes: XApiEx.Model.Expansions.t() | nil,
  meta: XApiEx.Model.PaginationMeta.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.