XApiEx.Model.SpaceFull (x_api_ex v1.0.0)

A full Space object with all available fields.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.SpaceFull{
  created_at: String.t() | nil,
  creator_id: String.t() | nil,
  ended_at: String.t() | nil,
  host_ids: [String.t()] | nil,
  id: String.t() | nil,
  invited_user_ids: [String.t()] | nil,
  is_ticketed: String.t() | nil,
  lang: String.t() | nil,
  participant_count: number() | nil,
  scheduled_start: String.t() | nil,
  speaker_ids: [String.t()] | nil,
  started_at: String.t() | nil,
  state: String.t() | nil,
  subscriber_count: number() | nil,
  title: String.t() | nil,
  topics: [XApiEx.Model.SpaceTopic.t()] | nil,
  updated_at: String.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.