XApiEx.Model.SpaceResponse (x_api_ex v1.0.0)

Response wrapper for a single space.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.SpaceResponse{data: XApiEx.Model.Space.t() | nil}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.