XApiEx.Model.User (x_api_ex v1.0.0)

A user object representing an X (Twitter) account.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.User{
  created_at: String.t() | nil,
  description: String.t() | nil,
  entities: XApiEx.Model.User.Entities.t() | nil,
  id: String.t() | nil,
  location: String.t() | nil,
  name: String.t() | nil,
  pinned_tweet_id: String.t() | nil,
  profile_image_url: String.t() | nil,
  protected: boolean() | nil,
  url: String.t() | nil,
  username: String.t() | nil,
  verified: boolean() | nil,
  withheld: term() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.