XApiEx.Model.User.Entities (x_api_ex v1.0.0)

Entity objects for a user profile.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.User.Entities{
  description: XApiEx.Model.User.Entities.Description.t() | nil,
  url: XApiEx.Model.User.Entities.Url.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.