XApiEx.Model.User.Entities.Url (x_api_ex v1.0.0)

URL entities within a user profile.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.User.Entities.Url{
  urls: [XApiEx.Model.User.Entities.Url.Item.t()] | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.