XApiEx.Model.UserResponse (x_api_ex v1.0.0)

Response wrapper for a single user object.

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.UserResponse{
  data: XApiEx.Model.User.t() | nil,
  errors: [XApiEx.Model.ApiError.t()] | nil,
  includes: XApiEx.Model.Expansions.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.