XApiEx.Model.UsersByUsername400ResponseErrorsInner (x_api_ex v1.0.0)

Summary

Functions

Deserializes nested structs within the given map into their respective model types.

Types

t()

@type t() :: %XApiEx.Model.UsersByUsername400ResponseErrorsInner{
  message: String.t() | nil,
  parameters:
    XApiEx.Model.UsersByUsername400ResponseErrorsInnerParameters.t() | nil
}

Functions

decode(value)

@spec decode(map()) :: t()

Deserializes nested structs within the given map into their respective model types.