XApiEx.Api.HideReplies (x_api_ex v1.0.0)
API calls for all endpoints tagged HideReplies.
Summary
Functions
Hide a reply Provides the ability to hide a reply to a Post. For full details, see the API reference for this endpoint. Sign up for the X API
Functions
@spec hide_a_reply(Tesla.Env.client(), String.t(), keyword()) :: {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.HideAReply200Response.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:error, Tesla.Env.t()}
Hide a reply Provides the ability to hide a reply to a Post. For full details, see the API reference for this endpoint. Sign up for the X API
Parameters
connection(XApiEx.Connection): Connection to serverid(String.t): Required. Enter a single Post ID.opts(keyword): Optional parameters:body(HideAReplyRequest):
Returns
{:ok, XApiEx.Model.HideAReply200Response.t}on success{:error, Tesla.Env.t}on failure