XApiEx.Api.ManageLists (x_api_ex v1.0.0)
API calls for all endpoints tagged ManageLists.
Summary
Functions
Create a list Allows the authenticated user to create a new List. For full details, see the API reference for this endpoint. Sign up for the X API
Delete a list Allows the authenticated user to delete a list they own. For full details, see the API reference for this endpoint. Sign up for the X API
Update a list Allows the authenticated user to update a List they own. For full details, see the API reference for this endpoint. Sign up for the X API
Functions
@spec create_a_list( Tesla.Env.client(), keyword() ) :: {:ok, XApiEx.Model.CreateAList201Response.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:error, Tesla.Env.t()}
Create a list Allows the authenticated user to create a new List. For full details, see the API reference for this endpoint. Sign up for the X API
Parameters
connection(XApiEx.Connection): Connection to serveropts(keyword): Optional parameters:body(CreateAListRequest):
Returns
{:ok, XApiEx.Model.CreateAList201Response.t}on success{:error, Tesla.Env.t}on failure
@spec delete_a_list(Tesla.Env.client(), String.t(), keyword()) :: {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.DeleteAPost200Response.t()} | {:error, Tesla.Env.t()}
Delete a list Allows the authenticated user to delete a list they own. For full details, see the API reference for this endpoint. Sign up for the X API
Parameters
connection(XApiEx.Connection): Connection to serverid(String.t): The ID of the List you wish to update the metadata of - the List must be owned by the authenticated useropts(keyword): Optional parameters
Returns
{:ok, XApiEx.Model.DeleteAPost200Response.t}on success{:error, Tesla.Env.t}on failure
@spec update_a_list(Tesla.Env.client(), String.t(), keyword()) :: {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.UpdateAList200Response.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:error, Tesla.Env.t()}
Update a list Allows the authenticated user to update a List they own. For full details, see the API reference for this endpoint. Sign up for the X API
Parameters
connection(XApiEx.Connection): Connection to serverid(String.t): The ID of the List you wish to update the metadata of - the List must be owned by the authenticated useropts(keyword): Optional parameters:body(UpdateAListRequest):
Returns
{:ok, XApiEx.Model.UpdateAList200Response.t}on success{:error, Tesla.Env.t}on failure