XApiEx.Api.Subtitles (x_api_ex v1.0.0)
API calls for all endpoints tagged Subtitles.
Summary
Functions
Create Media Subtitles
Allows an authenticated user to add subtitles to uploaded media. You can use this endpoint to provide subtitles for media. The media_id parameter identifies the media, while additional parameters define the subtitle language and file content. For full details, see the API reference for this endpoint. To get started, sign up for the X API.
Delete Media Subtitles
Allows an authenticated user to delete subtitles from uploaded media. You can use this endpoint to remove previously added subtitle information from media. The media_id parameter identifies the media, and specify other parameters to delete the subtitle. For full details, see the API reference for this endpoint. To get started, sign up for the X API.
Functions
@spec create_media_subtitles( Tesla.Env.client(), keyword() ) :: {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.CreateMediaSubtitles200Response.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:error, Tesla.Env.t()}
Create Media Subtitles
Allows an authenticated user to add subtitles to uploaded media. You can use this endpoint to provide subtitles for media. The media_id parameter identifies the media, while additional parameters define the subtitle language and file content. For full details, see the API reference for this endpoint. To get started, sign up for the X API.
Parameters
connection(XApiEx.Connection): Connection to serveropts(keyword): Optional parameters:body(CreateMediaSubtitlesRequest):
Returns
{:ok, XApiEx.Model.CreateMediaSubtitles200Response.t}on success{:error, Tesla.Env.t}on failure
@spec delete_media_subtitles( Tesla.Env.client(), keyword() ) :: {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.ApiError.t()} | {:ok, XApiEx.Model.DeleteAPost200Response.t()} | {:error, Tesla.Env.t()}
Delete Media Subtitles
Allows an authenticated user to delete subtitles from uploaded media. You can use this endpoint to remove previously added subtitle information from media. The media_id parameter identifies the media, and specify other parameters to delete the subtitle. For full details, see the API reference for this endpoint. To get started, sign up for the X API.
Parameters
connection(XApiEx.Connection): Connection to serveropts(keyword): Optional parameters:body(DeleteMediaSubtitlesRequest):
Returns
{:ok, XApiEx.Model.DeleteAPost200Response.t}on success{:error, Tesla.Env.t}on failure