XApiEx.Model.Media (x_api_ex v1.0.0)
A media object attached to a post.
Summary
Functions
Deserializes nested structs within the given map into their respective model types.
A media object attached to a post.
Deserializes nested structs within the given map into their respective model types.