XApiEx.Model.Place (x_api_ex v1.0.0)
A geographic place object.
Summary
Functions
Deserializes nested structs within the given map into their respective model types.
A geographic place object.
Deserializes nested structs within the given map into their respective model types.